@@ -173,7 +173,7 @@ namespace QtWayland {
         enum error {
             error_invalid_format = 0, // buffer format is not known
             error_invalid_stride = 1, // invalid size or stride during pool or buffer creation
-            error_invalid_fd = 2 // mmapping the file descriptor failed
+            error_invalid_fd = 2, // mmapping the file descriptor failed
         };
 
         enum format {
@@ -234,7 +234,7 @@ namespace QtWayland {
             format_yuv422 = 0x36315559, // 3 plane YCbCr format, 2x1 subsampled Cb (1) and Cr (2) planes
             format_yvu422 = 0x36315659, // 3 plane YCbCr format, 2x1 subsampled Cr (1) and Cb (2) planes
             format_yuv444 = 0x34325559, // 3 plane YCbCr format, non-subsampled Cb (1) and Cr (2) planes
-            format_yvu444 = 0x34325659 // 3 plane YCbCr format, non-subsampled Cr (1) and Cb (2) planes
+            format_yvu444 = 0x34325659, // 3 plane YCbCr format, non-subsampled Cr (1) and Cb (2) planes
         };
 
         struct ::wl_shm_pool *create_pool(int32_t fd, int32_t size);
@@ -310,7 +310,7 @@ namespace QtWayland {
             error_invalid_finish = 0, // finish request was called untimely
             error_invalid_action_mask = 1, // action mask contains invalid values
             error_invalid_action = 2, // action argument has an invalid value
-            error_invalid_offer = 3 // offer doesn't accept this request
+            error_invalid_offer = 3, // offer doesn't accept this request
         };
 
         void accept(uint32_t serial, const QString &mime_type);
@@ -364,7 +364,7 @@ namespace QtWayland {
 
         enum error {
             error_invalid_action_mask = 0, // action mask contains invalid values
-            error_invalid_source = 1 // source doesn't accept this request
+            error_invalid_source = 1, // source doesn't accept this request
         };
 
         void offer(const QString &mime_type);
@@ -428,7 +428,7 @@ namespace QtWayland {
         static const struct ::wl_interface *interface();
 
         enum error {
-            error_role = 0 // given wl_surface has another role
+            error_role = 0, // given wl_surface has another role
         };
 
         void start_drag(struct ::wl_data_source *source, struct ::wl_surface *origin, struct ::wl_surface *icon, uint32_t serial);
@@ -501,7 +501,7 @@ namespace QtWayland {
             dnd_action_none = 0, // no action
             dnd_action_copy = 1, // copy action
             dnd_action_move = 2, // move action
-            dnd_action_ask = 4 // ask action
+            dnd_action_ask = 4, // ask action
         };
 
         struct ::wl_data_source *create_data_source();
@@ -532,7 +532,7 @@ namespace QtWayland {
         static const struct ::wl_interface *interface();
 
         enum error {
-            error_role = 0 // given wl_surface has another role
+            error_role = 0, // given wl_surface has another role
         };
 
         struct ::wl_shell_surface *get_shell_surface(struct ::wl_surface *surface);
@@ -570,18 +570,18 @@ namespace QtWayland {
             resize_bottom_left = 6, // bottom and left edges
             resize_right = 8, // right edge
             resize_top_right = 9, // top and right edges
-            resize_bottom_right = 10 // bottom and right edges
+            resize_bottom_right = 10, // bottom and right edges
         };
 
         enum transient {
-            transient_inactive = 0x1 // do not set keyboard focus
+            transient_inactive = 0x1, // do not set keyboard focus
         };
 
         enum fullscreen_method {
             fullscreen_method_default = 0, // no preference, apply default policy
             fullscreen_method_scale = 1, // scale, preserve the surface's aspect ratio and center on output
             fullscreen_method_driver = 2, // switch output mode to the smallest mode that can fit the surface, add black borders to compensate size mismatch
-            fullscreen_method_fill = 3 // no upscaling, center on output and add black borders to compensate size mismatch
+            fullscreen_method_fill = 3, // no upscaling, center on output and add black borders to compensate size mismatch
         };
 
         void pong(uint32_t serial);
@@ -641,7 +641,7 @@ namespace QtWayland {
 
         enum error {
             error_invalid_scale = 0, // buffer scale value is invalid
-            error_invalid_transform = 1 // buffer transform value is invalid
+            error_invalid_transform = 1, // buffer transform value is invalid
         };
 
         void destroy();
@@ -696,7 +696,7 @@ namespace QtWayland {
         enum capability {
             capability_pointer = 1, // the seat has pointer devices
             capability_keyboard = 2, // the seat has one or more keyboards
-            capability_touch = 4 // the seat has touch devices
+            capability_touch = 4, // the seat has touch devices
         };
 
         struct ::wl_pointer *get_pointer();
@@ -743,24 +743,24 @@ namespace QtWayland {
         static const struct ::wl_interface *interface();
 
         enum error {
-            error_role = 0 // given wl_surface has another role
+            error_role = 0, // given wl_surface has another role
         };
 
         enum button_state {
             button_state_released = 0, // the button is not pressed
-            button_state_pressed = 1 // the button is pressed
+            button_state_pressed = 1, // the button is pressed
         };
 
         enum axis {
             axis_vertical_scroll = 0, // vertical axis
-            axis_horizontal_scroll = 1 // horizontal axis
+            axis_horizontal_scroll = 1, // horizontal axis
         };
 
         enum axis_source {
             axis_source_wheel = 0, // a physical wheel rotation
             axis_source_finger = 1, // finger on a touch surface
             axis_source_continuous = 2, // continuous coordinate space
-            axis_source_wheel_tilt = 3 // a physical wheel tilt
+            axis_source_wheel_tilt = 3, // a physical wheel tilt
         };
 
         void set_cursor(uint32_t serial, struct ::wl_surface *surface, int32_t hotspot_x, int32_t hotspot_y);
@@ -853,12 +853,12 @@ namespace QtWayland {
 
         enum keymap_format {
             keymap_format_no_keymap = 0, // no keymap; client must understand how to interpret the raw keycode
-            keymap_format_xkb_v1 = 1 // libxkbcommon compatible; to determine the xkb keycode, clients must add 8 to the key event keycode
+            keymap_format_xkb_v1 = 1, // libxkbcommon compatible; to determine the xkb keycode, clients must add 8 to the key event keycode
         };
 
         enum key_state {
             key_state_released = 0, // key is not pressed
-            key_state_pressed = 1 // key is pressed
+            key_state_pressed = 1, // key is pressed
         };
 
         void release();
@@ -1016,7 +1016,7 @@ namespace QtWayland {
             subpixel_horizontal_rgb = 2, // horizontal RGB
             subpixel_horizontal_bgr = 3, // horizontal BGR
             subpixel_vertical_rgb = 4, // vertical RGB
-            subpixel_vertical_bgr = 5 // vertical BGR
+            subpixel_vertical_bgr = 5, // vertical BGR
         };
 
         enum transform {
@@ -1027,12 +1027,12 @@ namespace QtWayland {
             transform_flipped = 4, // 180 degree flip around a vertical axis
             transform_flipped_90 = 5, // flip and rotate 90 degrees counter-clockwise
             transform_flipped_180 = 6, // flip and rotate 180 degrees counter-clockwise
-            transform_flipped_270 = 7 // flip and rotate 270 degrees counter-clockwise
+            transform_flipped_270 = 7, // flip and rotate 270 degrees counter-clockwise
         };
 
         enum mode {
             mode_current = 0x1, // indicates this is the current mode
-            mode_preferred = 0x2 // indicates this is the preferred mode
+            mode_preferred = 0x2, // indicates this is the preferred mode
         };
 
         void release();
@@ -1123,7 +1123,7 @@ namespace QtWayland {
         static const struct ::wl_interface *interface();
 
         enum error {
-            error_bad_surface = 0 // the to-be sub-surface is invalid
+            error_bad_surface = 0, // the to-be sub-surface is invalid
         };
 
         void destroy();
@@ -1154,7 +1154,7 @@ namespace QtWayland {
         static const struct ::wl_interface *interface();
 
         enum error {
-            error_bad_surface = 0 // wl_surface is not a sibling or the parent
+            error_bad_surface = 0, // wl_surface is not a sibling or the parent
         };
 
         void destroy();
